# ANTS-Hub - Copyright (C) Entr'ouvert

import django.contrib.admin.options
import django.contrib.admin.widgets
from django.contrib import admin

from ants_hub.admin import site

from . import models


class ConfigAdmin(admin.ModelAdmin):
    list_display = ['key', 'value']


class RaccordementAdmin(admin.ModelAdmin):
    list_display = ['name', 'short_apikey', 'created', 'last_update']
    search_fields = ['name', 'apikey', 'notes']
    ordering = ['name']

    def short_apikey(self, instance):
        return instance.apikey[:4] + '…'

    short_apikey.short_description = 'API key'


class CollectiviteAdmin(admin.ModelAdmin):
    list_display = ['raccordement', 'nom', 'url', 'source_id', 'created', 'last_update']
    search_fields = ['raccordement__name', 'nom']
    list_filter = ['raccordement']
    ordering = ['raccordement__name', 'nom']


class LieuAdmin(admin.ModelAdmin):
    list_display = ['collectivite', 'nom', 'created', 'last_update']
    search_fields = ['collectivite__raccordement__name', 'collectivite__nom', 'nom']
    list_filter = ['collectivite__raccordement']
    ordering = ['collectivite__raccordement__name', 'collectivite__nom', 'nom']


class PlageAdmin(admin.ModelAdmin):
    date_hierarchy = 'date'
    list_display = ['date', 'lieu', 'type_de_rdv', 'personnes', 'horaires', 'created', 'last_update']
    search_fields = ['lieu__collectivite__raccordement__name', 'lieu__collectivite__nom', 'lieu__nom']
    list_filter = ['lieu__collectivite']
    ordering = [
        'date',
        'lieu__collectivite__raccordement__name',
        'lieu__collectivite__nom',
        'lieu__nom',
        'horaires',
        'type_de_rdv',
        'personnes',
    ]


class RendezVousAdmin(admin.ModelAdmin):
    date_hierarchy = 'date'
    list_display = ['date', 'lieu', 'identifiant_predemande', 'created', 'last_update']
    list_filter = ['lieu__collectivite']
    search_fields = ['identifiant_predemande']
    ordering = [
        'date',
        'lieu__collectivite__raccordement__name',
        'lieu__collectivite__nom',
        'lieu__nom',
        'identifiant_predemande',
    ]

    def short_identifiant_predemande(self, instance):
        return instance.identifiant_predemande[:4] + '…'

    short_identifiant_predemande.short_description = 'Identifiant de prédemande'


django.contrib.admin.options.FORMFIELD_FOR_DBFIELD_DEFAULTS.update(
    {
        models.CharField: {
            'widget': django.contrib.admin.widgets.AdminTextInputWidget,
        },
        models.URLField: {
            'widget': django.contrib.admin.widgets.AdminURLFieldWidget,
        },
    }
)

site.site_header = 'Administration d\'ANTS-Hub'
site.site_title = 'ANTS-Hub'
site.register(models.Config, ConfigAdmin)
site.register(models.Raccordement, RaccordementAdmin)
site.register(models.Collectivite, CollectiviteAdmin)
site.register(models.Lieu, LieuAdmin)
site.register(models.Plage, PlageAdmin)
site.register(models.RendezVous, RendezVousAdmin)
